@@ -114,7 +114,10 @@ doseResponse_survFitCstExp <- function(x, time_LCx,
   # prameters
   mctot <- do.call("rbind", x$mcmc)
   kd <- 10^mctot[, "kd_log10"]
-  hb <- 10^mctot[, "hb_log10"]
+  # "hb" is not in survFit object of morse <v3.2.0
+  if("hb" %in% colnames(mctot)){
+    hb <- mctot[, "hb"]  
+  } else{ hb <- 10^mctot[, "hb_log10"] }
   
   # all theorical
   k <- 1:length(conc_range)
