@@ -24,7 +24,6 @@
 #' parameters drawn from the posterior distribution
 #' @param one.plot if \code{TRUE}, draws all the estimated curves in
 #' one plot instead of one plot per concentration.
-#' @param adddata if \code{TRUE}, adds the observed data to the plot
 #' @param mcmc_size A numerical value refering by default to the size of the mcmc in object \code{survFitPredict}.
 #'  This option is specific to \code{survFitPredict} objects for which computing time may be long.
 #'  \code{mcmc_size} can be used to reduce the number of mcmc samples in order to speed up
@@ -68,14 +67,13 @@ plot.survFitPredict <- function(x,
                                main = NULL,
                                spaghetti = FALSE,
                                one.plot = FALSE,
-                               adddata = FALSE,
                                mcmc_size = NULL,
                                ...) {
 
   df_prediction <-  x$df_quantile
   df_spaghetti <-  x$df_spaghetti
+
   # Plot
-  
   plt <- ggplot() +
     theme_minimal() +
     scale_x_continuous(name = xlab) +
@@ -106,13 +104,12 @@ plot.survFitPredict <- function(x,
                   aes(x = time, ymin = qinf95,ymax = qsup95, group = replicate),
                   fill = "grey70", alpha = 0.4)
   }
-  
   # Prediction
   plt <- plt +
     geom_line(data = df_prediction,
               aes(x = time, y = q50, group = replicate),
               col="orange", size = 1)
-  
+
   # facetting
   if(one.plot == FALSE){
     plt <- plt + facet_wrap(~ replicate)
